@@ -57,8 +57,8 @@ class GeoStylesGroup(group.Group):
 
 def advanced_group_fields():
     form_fields = field.Fields(IGeoSettings).select('yahooapi',
-                                                    'default_layers',
-                                                    'imgpath')
+                                            'default_layers',
+                                            'imgpath',)
 
     default_layer_field = form_fields['default_layers']
     default_layer_field.field.value_type = Choice(title=_(u"Layers"),
@@ -212,7 +212,7 @@ class MarkerEditLayer(MapLayer):
 
     name = "markeredit"
 
-    jsfactory = """
+    jsfactory = u"""
     function() { return new OpenLayers.Layer.Vector('Marker',
                                     {renderOptions: {yOrdering: true}});}
     """
